"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = detectFramework;

var _frameworks = _interopRequireDefault(require("./frameworks"));

var _path = require("path");

var _install = _interopRequireDefault(require("./install"));

var _chalk = _interopRequireDefault(require("chalk"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Detects the framework being used by the project in the current working
 * directory and installs the `xdn-*` library needed to build it for deployment
 * on the XDN, as well as `@xdn/core`.
 * @return {String} The command to run to build the app for deployment on the XDN.
 */
async function detectFramework() {
  const packageJson = require((0, _path.join)(process.cwd(), 'package.json'));

  const framework = _frameworks.default.find(framework => !!packageJson.dependencies[framework.dependency]);

  if (framework == null) {
    console.log(`> ${_chalk.default.red('We were unable to detect your web framework. Aborting deployment.')}`);
    return process.exit(1);
  }

  console.log(`> detected ${_chalk.default.green(framework.name)}`);
  await (0, _install.default)('@xdn/core');
  await (0, _install.default)(framework.builder);
  return framework;
}

module.exports = exports.default;