"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = install;

var _ora = _interopRequireDefault(require("ora"));

var _chalk = _interopRequireDefault(require("chalk"));

var _child_process = require("child_process");

var _path = require("path");

var _isPackageInstalled = _interopRequireDefault(require("./isPackageInstalled"));

var _fs = require("fs");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Installs a package from npm.
 * @param {String} lib The name of the package to install
 * @return {Promise}
 */
function install(lib) {
  if ((0, _isPackageInstalled.default)(lib)) return Promise.resolve();
  return new Promise((resolve, reject) => {
    const message = `installing ${_chalk.default.green(lib)}...`;
    const spinner = (0, _ora.default)(message).start();
    let command = 'npm install --save';

    if ((0, _fs.existsSync)((0, _path.join)('yarn.lock'))) {
      command = 'yarn add';
    }

    (0, _child_process.exec)(`${command} ${lib}`, error => {
      if (error) {
        spinner.fail(`${message} failed.`);
        console.error(error);
        reject(error);
      } else {
        spinner.succeed(`${message} done.`);
        resolve();
      }
    });
  });
}

module.exports = exports.default;